pub struct TimedTransactionSource {
pub source: TransactionSource,
pub timestamp: Option<Instant>,
}Expand description
A transaction source that includes a timestamp indicating when the transaction was submitted.
Fields
source: TransactionSourceThe original source of the transaction.
timestamp: Option<Instant>The time at which the transaction was submitted.
Implementations
Sourceimpl TimedTransactionSource
impl TimedTransactionSource
Sourcepub fn new_in_block(with_timestamp: bool) -> Self
pub fn new_in_block(with_timestamp: bool) -> Self
Creates a new instance with an internal TransactionSource::InBlock source and an optional
timestamp.
Sourcepub fn new_external(with_timestamp: bool) -> Self
pub fn new_external(with_timestamp: bool) -> Self
Creates a new instance with an internal TransactionSource::External source and an optional
timestamp.
Sourcepub fn new_local(with_timestamp: bool) -> Self
pub fn new_local(with_timestamp: bool) -> Self
Creates a new instance with an internal TransactionSource::Local source and an optional
timestamp.
Sourcepub fn from_transaction_source(
source: TransactionSource,
with_timestamp: bool,
) -> Self
pub fn from_transaction_source( source: TransactionSource, with_timestamp: bool, ) -> Self
Creates a new instance with an given source and an optional timestamp.